@@ -1,8 +1,6 @@
 __title__ = "Euskalmet Python API"
-__description__ = (
-    "Python API for Euskalmet (https://www.euskalmet.euskadi.eus/hasiera/) open data"
-)
+__description__ = "Python API for Euskalmet (https://www.euskalmet.euskadi.eus/hasiera/) open data"
 __url__ = "https://github.com/r3v1/python-euskalmet"
-__version__ = "0.2.1"
+__version__ = "0.3.4"
 __author__ = "David Revillas"
 __author_email__ = "r3v1@pm.me"
